# -*- coding: utf-8 -*-
# (c) 2013 Bright Interactive Limited. All rights reserved.
# http://www.bright-interactive.com | info@bright-interactive.com


CONSTANT_IN_GRANDCHILD_FILE = 'in grandchild file'
